@@ -83,7 +83,7 @@ class Project:
         except Exception as exc:
             raise FileLoadError(
                 "Failed to load Pipfile (path: "
-                f"{os.getcwd() if not pipfile_path else os.path.abspath(pipfile_path)}: {str(exc)}"
+                f"{os.getcwd() if not pipfile_path else os.path.abspath(pipfile_path)}: {str(exc)})"
             ) from exc
 
         pipfile_lock = None
@@ -93,7 +93,8 @@ class Project:
             except Exception as exc:
                 raise FileLoadError(
                     f"Failed to load Pipfile.lock "
-                    f"(path: {os.getcwd() if not pipfile_lock_path else os.path.abspath(pipfile_lock_path)}: {str(exc)}"
+                    f"(path: "
+                    f"{os.getcwd() if not pipfile_lock_path else os.path.abspath(pipfile_lock_path)}: {str(exc)})"
                 ) from exc
 
         return cls(
@@ -682,6 +683,16 @@ class Project:
 
     def check_provenance(self, whitelisted_sources: list = None, digests_fetcher: DigestsFetcherBase = None) -> List:
         """Check provenance/origin of packages that are stated in the project."""
+        if self.pipfile_lock and self.pipfile.hash() != self.pipfile_lock.meta.hash:
+            return [
+                {
+                    "type": "ERROR",
+                    "id": "INVALID-LOCK-HASH",
+                    "justification": f"Hash recorded in the lockfile ({self.pipfile_lock.meta.hash['sha256']!r}) does "
+                    f"not correspond to the hash computed ({self.pipfile.hash()['sha256']!r})",
+                }
+            ]
+
         digests_fetcher = digests_fetcher or PythonDigestsFetcher(list(self.pipfile.meta.sources.values()))
         findings, _ = self._index_scan(digests_fetcher)
         findings.extend(self._check_sources(whitelisted_sources))
@@ -717,7 +728,12 @@ class Project:
         return source
 
     def add_package(
-        self, package_name: str, package_version: str = None, *, source: Source = None, develop: bool = False
+        self,
+        package_name: str,
+        package_version: Optional[str] = None,
+        *,
+        source: Optional[Source] = None,
+        develop: bool = False,
     ):
         """Add the given package to project.
 
